@@ -3,7 +3,7 @@ package CGI::Alternatives;
 use strict;
 use warnings;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 1;
 
@@ -17,7 +17,7 @@ CGI::Alternatives - Documentation for alternative solutions to CGI.pm
 
 =head1 VERSION
 
-0.15
+0.16
 
 =head1 DESCRIPTION
 
@@ -213,60 +213,6 @@ Please don't write your own template engine. If you want to completely split
 out your html and still have some sort of templating system there are modules
 to do that, such as L<HTML::Zoom>.
 
-=head1 PSGI/Plack
-
-L<http://metacpan.org/release/PSGI>
-
-L<http://metacpan.org/release/Plack>
-
-L<http://plackperl.org/>
-
-PSGI is an interface between Perl web applications and web servers, and Plack
-is a Perl module and toolkit that contains PSGI middleware, helpers and
-adapters to web servers.
-
-Plack is a collection of building blocks to create web applications, ranging from
-quick & easy scripts, to the foundations of building larger frameworks.
-
-    #!/usr/bin/env perl
-
-    use strict;
-    use warnings;
-    use feature qw/ state /;
-
-    use FindBin qw/ $Bin /;
-    use Template;
-    use Plack::Request;
-    use Plack::Response;
-
-    my $app = sub {
-        my $req = Plack::Request->new( shift );
-        my $res = Plack::Response->new( 200 );
-
-        state $tt  = Template->new({
-            INCLUDE_PATH => "$Bin/templates",
-        });
-
-        my $out;
-
-        $tt->process(
-            "example_form.html.tt",
-            {
-                result => $req->parameters->{'user_input'},
-            },
-            \$out,
-        ) or die $tt->error;
-
-        $res->body( $out );
-        $res->finalize;
-    };
-
-To run this script:
-
-    plackup examples/plack_psgi.pl
-
-That makes the script (the "app") available at http://*:5000
-
 =head1 Mojolicious
 
 CPAN: L<http://metacpan.org/release/Mojolicious>
@@ -466,6 +412,78 @@ Then running the server:
 
 Again makes the page available at http://*:3000/example_form
 
+=head1 PSGI/Plack
+
+Raw Plack is lower-level than Mojolicious so the code will be more verbose,
+but Plack is probably a closer match to CGI.pm in terms of the things you're
+having to handle.
+
+L<http://metacpan.org/release/PSGI>
+
+L<http://metacpan.org/release/Plack>
+
+L<http://plackperl.org/>
+
+PSGI is an interface between Perl web applications and web servers, and Plack
+is a Perl module and toolkit that contains PSGI middleware, helpers and
+adapters to web servers.
+
+Plack is a collection of building blocks to create web applications, ranging from
+quick & easy scripts, to the foundations of building larger frameworks.
+
+=head2 Plack As A Peristant Process
+
+    #!/usr/bin/env perl
+
+    use strict;
+    use warnings;
+    use feature qw/ state /;
+
+    use FindBin qw/ $Bin /;
+    use Template;
+    use Plack::Request;
+    use Plack::Response;
+
+    my $app = sub {
+        my $req = Plack::Request->new( shift );
+        my $res = Plack::Response->new( 200 );
+
+        state $tt  = Template->new({
+            INCLUDE_PATH => "$Bin/templates",
+        });
+
+        my $out;
+
+        $tt->process(
+            "example_form.html.tt",
+            {
+                result => $req->parameters->{'user_input'},
+            },
+            \$out,
+        ) or die $tt->error;
+
+        $res->body( $out );
+        $res->finalize;
+    };
+
+To run this script:
+
+    plackup examples/plack_psgi.pl
+
+That makes the script (the "app") available at http://*:5000
+
+=head2 Plack As A Run On Demand CGI Script
+
+If your CGI script only runs once in a while, and doesn't need to be persistant,
+then you can use Plack the same way and not have to worry about deployment
+concerns such has having to restart a process. To do so requires adding:
+
+    use Plack::Handler::CGI;
+    Plack::Handler::CGI->new->run($app);
+
+to the end of the script. This will allow it to be exec'd correctly by the
+upfront webserver and to behave like a standalone CGI script
+
 =head1 Others
 
 The three (four) examples above are the "big three", currently very popular
